@@ -1,21 +1,29 @@
-from pymint.constraints.constraint import LayoutConstraint
-from typing import Dict
-from pymint.mintcomponent import MINTComponent
 from enum import Enum
+from typing import Dict
+
+from pymint.constraints.constraint import LayoutConstraint
+from pymint.mintcomponent import MINTComponent
 
 
 class ComponentOrientation(Enum):
+    """Enum ot represent component's relative orientation"""
+
     HORIZONTAL = 0
     VERTICAL = 1
 
 
 class OrientationConstraint(LayoutConstraint):
+    """Layout constraint that setups relative orientations for a
+    number of components inside a single layer
+
+    """
+
     def __init__(self) -> None:
         """Creates an instance of the orientation constraint"""
         super().__init__()
-        self.__orientation_map: Dict[MINTComponent, ComponentOrientation] = dict()
+        self.__orientation_map: Dict[MINTComponent, ComponentOrientation] = {}
 
-    def add_component(
+    def add_component_orientation_pair(
         self, component: MINTComponent, orientation: ComponentOrientation
     ) -> None:
         """Adds a component onto the constraint
@@ -32,6 +40,7 @@ class OrientationConstraint(LayoutConstraint):
         """Retuns the map of all the components and their corresponding orientation
 
         Returns:
-            Dict[MINTComponent, ComponentOrientation]: dict mapping the components and thier orientations
+            Dict[MINTComponent, ComponentOrientation]: dict mapping the components and
+             their orientations
         """
         return self.__orientation_map
